@@ -240,7 +240,6 @@
 #endif
 #pragma clang diagnostic pop
 #undef _BACKWARD_BACKWARD_WARNING_H
-#include "etc/cling/Interpreter/DynamicExprInfo.h"
 #include "etc/cling/Interpreter/DynamicLookupRuntimeUniverse.h"
 #include "etc/cling/Interpreter/DynamicLookupLifetimeHandler.h"
 #include "etc/cling/Interpreter/Exception.h"
@@ -249,29 +248,30 @@
 #include "etc/cling/Interpreter/RuntimeOptions.h"
 #include "etc/cling/Interpreter/Value.h"
 #include "etc/cling/Interpreter/Visibility.h"
+#define ROOFIT_BUILDS_ITSELF
 // ./core/clingutils/G__forward_listDict.cxx
 #include "forward_list"
 // ./core/clingutils/G__dequeDict.cxx
 #include "deque"
-// ./core/clingutils/G__vectorDict.cxx
-#include "vector"
 // ./core/clingutils/G__listDict.cxx
 #include "list"
+// ./core/clingutils/G__vectorDict.cxx
+#include "vector"
 // ./core/clingutils/G__multisetDict.cxx
 #include "set"
+// ./core/clingutils/G__setDict.cxx
+#include "set"
 // ./core/clingutils/G__multimapDict.cxx
 #include "map"
-// ./core/clingutils/G__setDict.cxx
-#include "set"
-// ./core/clingutils/G__multimap2Dict.cxx
-#include "map"
-// ./core/clingutils/G__mapDict.cxx
+// ./core/clingutils/G__map2Dict.cxx
 #include "map"
 // ./core/clingutils/G__unordered_setDict.cxx
 #include "unordered_set"
 // ./core/clingutils/G__unordered_multisetDict.cxx
 #include "unordered_set"
-// ./core/clingutils/G__map2Dict.cxx
+// ./core/clingutils/G__multimap2Dict.cxx
+#include "map"
+// ./core/clingutils/G__mapDict.cxx
 #include "map"
 // ./core/clingutils/G__valarrayDict.cxx
 #include "valarray"
@@ -281,6 +281,12 @@
 #include "unordered_map"
 // ./core/clingutils/G__unordered_mapDict.cxx
 #include "unordered_map"
+// ./core/imt/G__Imt.cxx
+#include "ROOT/TTaskGroup.hxx"
+#include "ROOT/RTaskArena.hxx"
+#include "ROOT/RSlotStack.hxx"
+#include "ROOT/TExecutor.hxx"
+#include "ROOT/TThreadExecutor.hxx"
 // ./core/multiproc/G__MultiProc.cxx
 #include "MPCode.h"
 #include "MPSendRecv.h"
@@ -314,13 +320,6 @@
 #include "ROOT/TRWSpinLock.hxx"
 #include "ROOT/TSpinMutex.hxx"
 #include "ROOT/TThreadedObject.hxx"
-// ./core/imt/G__Imt.cxx
-#include "ROOT/TFuture.hxx"
-#include "ROOT/TTaskGroup.hxx"
-#include "ROOT/RTaskArena.hxx"
-#include "ROOT/RSlotStack.hxx"
-#include "ROOT/TExecutor.hxx"
-#include "ROOT/TThreadExecutor.hxx"
 // ./math/mathcore/G__MathCore.cxx
 #include "Fit/BasicFCN.h"
 #include "Fit/BinData.h"
@@ -429,7 +428,6 @@
 #include "Math/GSLSimAnMinimizer.h"
 #include "Math/InterpolationTypes.h"
 #include "Math/Interpolator.h"
-#include "Math/KelvinFunctions.h"
 #include "Math/MCParameters.h"
 #include "Math/PdfFuncMathMore.h"
 #include "Math/Polynomial.h"
@@ -797,18 +795,21 @@
 #include "TGraph.h"
 #include "TGraphSmooth.h"
 #include "TGraphTime.h"
+#include "TScatter.h"
 #include "TH1C.h"
 #include "TH1D.h"
 #include "TH1F.h"
 #include "TH1.h"
 #include "TH1I.h"
 #include "TH1K.h"
+#include "TH1L.h"
 #include "TH1S.h"
 #include "TH2C.h"
 #include "TH2D.h"
 #include "TH2F.h"
 #include "TH2.h"
 #include "TH2I.h"
+#include "TH2L.h"
 #include "TH2Poly.h"
 #include "TH2S.h"
 #include "TH3C.h"
@@ -816,6 +817,7 @@
 #include "TH3F.h"
 #include "TH3.h"
 #include "TH3I.h"
+#include "TH3L.h"
 #include "TH3S.h"
 #include "THLimitsFinder.h"
 #include "THnBase.h"
@@ -879,12 +881,6 @@
 #include "TSpectrumTransform.h"
 // ./hist/spectrumpainter/G__SpectrumPainter.cxx
 #include "TSpectrum2Painter.h"
-// ./hist/unfold/G__Unfold.cxx
-#include "TUnfold.h"
-#include "TUnfoldBinning.h"
-#include "TUnfoldBinningXML.h"
-#include "TUnfoldDensity.h"
-#include "TUnfoldSys.h"
 // ./hist/hbook/G__Hbook.cxx
 #include "THbookBranch.h"
 #include "THbookFile.h"
@@ -996,6 +992,7 @@
 #include "ROOT/RTreeViewer.hxx"
 // ./tree/dataframe/G__ROOTDataFrame.cxx
 #include "ROOT/RCsvDS.hxx"
+#include "ROOT/RVecDS.hxx"
 #include "ROOT/RDataFrame.hxx"
 #include "ROOT/RDataSource.hxx"
 #include "ROOT/RDFHelpers.hxx"
@@ -1019,6 +1016,7 @@
 #include "ROOT/RDF/RSampleInfo.hxx"
 #include "ROOT/RDF/RDefineBase.hxx"
 #include "ROOT/RDF/RDefine.hxx"
+#include "ROOT/RDF/RDefinePerSample.hxx"
 #include "ROOT/RDF/RDefineReader.hxx"
 #include "ROOT/RDF/RDSColumnReader.hxx"
 #include "ROOT/RDF/RColumnReaderBase.hxx"
@@ -1061,21 +1059,29 @@
 #include "ROOT/RColumnModel.hxx"
 #include "ROOT/REntry.hxx"
 #include "ROOT/RField.hxx"
-#include "ROOT/RFieldValue.hxx"
 #include "ROOT/RFieldVisitor.hxx"
 #include "ROOT/RMiniFile.hxx"
 #include "ROOT/RNTuple.hxx"
+#include "ROOT/RNTupleCollectionWriter.hxx"
 #include "ROOT/RNTupleDescriptor.hxx"
+#include "ROOT/RNTupleFillContext.hxx"
+#include "ROOT/RNTupleImtTaskScheduler.hxx"
 #include "ROOT/RNTupleMerger.hxx"
 #include "ROOT/RNTupleMetrics.hxx"
 #include "ROOT/RNTupleModel.hxx"
-#include "ROOT/RNTupleOptions.hxx"
+#include "ROOT/RNTupleParallelWriter.hxx"
+#include "ROOT/RNTupleReadOptions.hxx"
+#include "ROOT/RNTupleReader.hxx"
 #include "ROOT/RNTupleSerialize.hxx"
 #include "ROOT/RNTupleUtil.hxx"
 #include "ROOT/RNTupleView.hxx"
+#include "ROOT/RNTupleWriteOptions.hxx"
+#include "ROOT/RNTupleWriteOptionsDaos.hxx"
+#include "ROOT/RNTupleWriter.hxx"
 #include "ROOT/RNTupleZip.hxx"
 #include "ROOT/RPage.hxx"
 #include "ROOT/RPageAllocator.hxx"
+#include "ROOT/RPageNullSink.hxx"
 #include "ROOT/RPagePool.hxx"
 #include "ROOT/RPageSinkBuf.hxx"
 #include "ROOT/RPageSourceFriends.hxx"
@@ -1083,8 +1089,10 @@
 #include "ROOT/RPageStorageFile.hxx"
 // ./tree/ntupleutil/G__ROOTNTupleUtil.cxx
 #include "ROOT/RNTupleImporter.hxx"
+#include "ROOT/RNTupleInspector.hxx"
 // ./io/io/G__RIO.cxx
 #include "ROOT/RRawFile.hxx"
+#include "ROOT/RRawFileTFile.hxx"
 #include "ROOT/RRawFileUnix.hxx"
 #include "ROOT/RIoUring.hxx"
 #include "ROOT/TBufferMerger.hxx"
@@ -1204,6 +1212,7 @@
 #include "ROOT/RPaveText.hxx"
 #include "ROOT/RText.hxx"
 // ./graf2d/gpad/G__Gpad.cxx
+#include "TAnnotation.h"
 #include "TAttCanvas.h"
 #include "TButton.h"
 #include "TCanvas.h"
@@ -1672,17 +1681,16 @@
 #include "TMVA/VarTransformHandler.h"
 #include "TMVA/Version.h"
 #include "TMVA/Volume.h"
-#include "TMVA/TreeInference/PythonHelpers.hxx"
-#include "TMVA/TreeInference/BranchlessTree.hxx"
-#include "TMVA/TreeInference/Forest.hxx"
-#include "TMVA/TreeInference/Objectives.hxx"
-#include "TMVA/RTensor.hxx"
+// ./tmva/tmva/G__TMVAUtils.cxx
 #include "TMVA/RTensorUtils.hxx"
 #include "TMVA/RStandardScaler.hxx"
 #include "TMVA/RReader.hxx"
 #include "TMVA/RInferenceUtils.hxx"
 #include "TMVA/RBDT.hxx"
 #include "TMVA/RSofieReader.hxx"
+#include "TMVA/RBatchGenerator.hxx"
+#include "TMVA/RBatchLoader.hxx"
+#include "TMVA/RChunkLoader.hxx"
 // ./tmva/tmvagui/G__TMVAGui.cxx
 #include "TMVA/BDT.h"
 #include "TMVA/BDTControlPlots.h"
@@ -1731,6 +1739,7 @@
 #include "TMVA/PyMethodBase.h"
 // ./tmva/sofie/G__ROOTTMVASofie.cxx
 #include "TMVA/OperatorList.hxx"
+#include "TMVA/RModel_Base.hxx"
 #include "TMVA/RModel.hxx"
 #include "TMVA/ROperator.hxx"
 #include "TMVA/ROperator_BasicUnary.hxx"
@@ -1758,22 +1767,31 @@
 #include "TMVA/ROperator_Custom.hxx"
 #include "TMVA/ROperator_LayerNormalization.hxx"
 #include "TMVA/ROperator_Expand.hxx"
+#include "TMVA/ROperator_Erf.hxx"
+#include "TMVA/ROperator_Swish.hxx"
+#include "TMVA/ROperator_Elu.hxx"
+#include "TMVA/ROperator_Comparision.hxx"
+#include "TMVA/ROperator_EyeLike.hxx"
+#include "TMVA/ROperator_Range.hxx"
 #include "TMVA/SOFIE_common.hxx"
 #include "TMVA/SOFIEHelpers.hxx"
+#include "TMVA/FunctionList.hxx"
+#include "TMVA/RModel_GNN.hxx"
+#include "TMVA/RModel_GraphIndependent.hxx"
+#include "TMVA/RFunction.hxx"
+#include "TMVA/RFunction_MLP.hxx"
+#include "TMVA/RFunction_Sum.hxx"
+#include "TMVA/RFunction_Mean.hxx"
 // ./roofit/roofitcore/G__RooFitCore.cxx
-#include "RooFit/Config.h"
-#include "RooFit/Detail/DataMap.h"
-#include "RooFit/Detail/NormalizationHelpers.h"
-#include "RooFit/Floats.h"
-#include "RooFit/ModelConfig.h"
 #include "Roo1DTable.h"
+#include "RooAICRegistry.h"
 #include "RooAbsAnaConvPdf.h"
 #include "RooAbsArg.h"
 #include "RooAbsBinning.h"
+#include "RooAbsCache.h"
+#include "RooAbsCacheElement.h"
 #include "RooAbsCachedPdf.h"
 #include "RooAbsCachedReal.h"
-#include "RooAbsCacheElement.h"
-#include "RooAbsCache.h"
 #include "RooAbsCategory.h"
 #include "RooAbsCategoryLValue.h"
 #include "RooAbsCollection.h"
@@ -1786,127 +1804,131 @@
 #include "RooAbsLValue.h"
 #include "RooAbsMCStudyModule.h"
 #include "RooAbsMoment.h"
-#include "RooAbsOptTestStatistic.h"
 #include "RooAbsPdf.h"
 #include "RooAbsProxy.h"
 #include "RooAbsReal.h"
 #include "RooAbsRealLValue.h"
-#include "RooAbsRootFinder.h"
 #include "RooAbsSelfCachedPdf.h"
 #include "RooAbsSelfCachedReal.h"
-#include "RooAbsString.h"
 #include "RooAbsStudy.h"
-#include "RooAbsTestStatistic.h"
-#include "RooAdaptiveIntegratorND.h"
 #include "RooAddGenContext.h"
-#include "RooAddition.h"
 #include "RooAddModel.h"
 #include "RooAddPdf.h"
-#include "RooAICRegistry.h"
+#include "RooAddition.h"
 #include "RooArgList.h"
 #include "RooArgProxy.h"
 #include "RooArgSet.h"
-#include "RooBinIntegrator.h"
+#include "RooBinSamplingPdf.h"
+#include "RooBinWidthFunction.h"
 #include "RooBinnedGenContext.h"
-#include "RooBinningCategory.h"
 #include "RooBinning.h"
+#include "RooBinningCategory.h"
 #include "RooBrentRootFinder.h"
+#include "RooCacheManager.h"
 #include "RooCachedPdf.h"
 #include "RooCachedReal.h"
-#include "RooCacheManager.h"
 #include "RooCategory.h"
 #include "RooCategoryProxy.h"
 #include "RooChangeTracker.h"
-#include "RooChi2Var.h"
 #include "RooClassFactory.h"
 #include "RooCmdArg.h"
 #include "RooCmdConfig.h"
 #include "RooCollectionProxy.h"
 #include "RooCompositeDataStore.h"
-#include "RooConstraintSum.h"
 #include "RooConstVar.h"
+#include "RooConstraintSum.h"
 #include "RooConvCoefVar.h"
 #include "RooConvGenContext.h"
-#include "RooConvIntegrandBinding.h"
 #include "RooCurve.h"
 #include "RooCustomizer.h"
+#include "RooDLLSignificanceMCSModule.h"
 #include "RooDataHist.h"
 #include "RooDataHistSliceIter.h"
 #include "RooDataProjBinding.h"
 #include "RooDataSet.h"
-#include "RooDataWeightedAverage.h"
 #include "RooDerivative.h"
 #include "RooDirItem.h"
-#include "RooDLLSignificanceMCSModule.h"
 #include "RooDouble.h"
 #include "RooEffGenContext.h"
-#include "RooEfficiency.h"
 #include "RooEffProd.h"
+#include "RooEfficiency.h"
 #include "RooEllipse.h"
 #include "RooErrorHandler.h"
 #include "RooErrorVar.h"
 #include "RooExpensiveObjectCache.h"
+#include "RooExtendPdf.h"
 #include "RooExtendedBinding.h"
 #include "RooExtendedTerm.h"
-#include "RooExtendPdf.h"
-#include "RooFactoryWSTool.h"
 #include "RooFFTConvPdf.h"
+#include "RooFactoryWSTool.h"
 #include "RooFirstMoment.h"
 #include "RooFit.h"
+#include "RooFit/Config.h"
+#include "RooFit/Detail/BatchModeDataHelpers.h"
+#include "RooFit/Detail/CodeSquashContext.h"
+#include "RooFit/Detail/MathFuncs.h"
+#include "RooFit/Detail/NormalizationHelpers.h"
+#include "RooFit/EvalContext.h"
+#include "RooFit/Evaluator.h"
+#include "RooFit/Floats.h"
+#include "RooFit/ModelConfig.h"
+#include "RooFit/TestStatistics/LikelihoodGradientWrapper.h"
+#include "RooFit/TestStatistics/LikelihoodWrapper.h"
+#include "RooFit/TestStatistics/RooAbsL.h"
+#include "RooFit/TestStatistics/RooBinnedL.h"
+#include "RooFit/TestStatistics/RooRealL.h"
+#include "RooFit/TestStatistics/RooSubsidiaryL.h"
+#include "RooFit/TestStatistics/RooSumL.h"
+#include "RooFit/TestStatistics/RooUnbinnedL.h"
+#include "RooFit/TestStatistics/buildLikelihood.h"
+#include "RooFit/TestStatistics/SharedOffset.h"
+#include "RooFitLegacy/RooCatTypeLegacy.h"
+#include "RooFitLegacy/RooCategorySharedProperties.h"
+#include "RooFitLegacy/RooTreeData.h"
 #include "RooFitResult.h"
-#include "RooFormula.h"
 #include "RooFormulaVar.h"
 #include "RooFracRemainder.h"
+#include "RooFuncWrapper.h"
 #include "RooFunctor.h"
 #include "RooGenContext.h"
-#include "RooGenericPdf.h"
 #include "RooGenFitStudy.h"
-#include "RooGenFunction.h"
-#include "RooGenProdProj.h"
+#include "RooGenericPdf.h"
 #include "RooGlobalFunc.h"
-#include "RooGrid.h"
+#include "RooHelpers.h"
+#include "RooHist.h"
 #include "RooHistError.h"
 #include "RooHistFunc.h"
-#include "RooHist.h"
 #include "RooHistPdf.h"
-#include "RooImproperIntegrator1D.h"
-#include "RooIntegrator1D.h"
-#include "RooIntegrator2D.h"
-#include "RooIntegratorBinding.h"
-#include "RooInt.h"
 #include "RooInvTransform.h"
+#include "RooLinTransBinning.h"
 #include "RooLinearCombination.h"
 #include "RooLinearVar.h"
-#include "RooLinkedListElem.h"
 #include "RooLinkedList.h"
+#include "RooLinkedListElem.h"
 #include "RooLinkedListIter.h"
-#include "RooLinTransBinning.h"
 #include "RooListProxy.h"
-#include "RooMath.h"
-#include "RooMappedCategory.h"
-#include "RooMCIntegrator.h"
 #include "RooMCStudy.h"
+#include "RooMappedCategory.h"
+#include "RooMath.h"
 #include "RooMinimizer.h"
 #include "RooMoment.h"
 #include "RooMsgService.h"
 #include "RooMultiCategory.h"
-#include "RooMultiGenFunction.h"
 #include "RooMultiVarGaussian.h"
 #include "RooNameReg.h"
-#include "RooNLLVar.h"
 #include "RooNormSetCache.h"
-#include "RooNumber.h"
 #include "RooNumCdf.h"
-#include "RooNumConvolution.h"
 #include "RooNumConvPdf.h"
+#include "RooNumConvolution.h"
 #include "RooNumGenConfig.h"
 #include "RooNumIntConfig.h"
 #include "RooNumIntFactory.h"
 #include "RooNumRunningInt.h"
+#include "RooNumber.h"
 #include "RooObjCacheManager.h"
 #include "RooParamBinning.h"
-#include "RooPlotable.h"
 #include "RooPlot.h"
+#include "RooPlotable.h"
 #include "RooPolyFunc.h"
 #include "RooPolyVar.h"
 #include "RooPrintable.h"
@@ -1918,17 +1940,14 @@
 #include "RooProofDriverSelector.h"
 #include "RooPullVar.h"
 #include "RooQuasiRandomGenerator.h"
-#include "RooRatio.h"
 #include "RooRandom.h"
 #include "RooRandomizeParamMCSModule.h"
 #include "RooRangeBinning.h"
 #include "RooRangeBoolean.h"
-#include "RooRealAnalytic.h"
+#include "RooRatio.h"
 #include "RooRealBinding.h"
 #include "RooRealConstant.h"
 #include "RooRealIntegral.h"
-#include "RooRealMPFE.h"
-#include "RooTemplateProxy.h"
 #include "RooRealProxy.h"
 #include "RooRealSumFunc.h"
 #include "RooRealSumPdf.h"
@@ -1936,56 +1955,39 @@
 #include "RooRealVarSharedProperties.h"
 #include "RooRecursiveFraction.h"
 #include "RooRefCountList.h"
-#include "RooSTLRefCountList.h"
 #include "RooResolutionModel.h"
-#include "RooScaledFunc.h"
+#include "RooSTLRefCountList.h"
 #include "RooSecondMoment.h"
-#include "RooSegmentedIntegrator1D.h"
-#include "RooSegmentedIntegrator2D.h"
 #include "RooSetProxy.h"
 #include "RooSharedProperties.h"
 #include "RooSimGenContext.h"
 #include "RooSimSplitGenContext.h"
-#include "RooSimultaneous.h"
 #include "RooSimWSTool.h"
+#include "RooSimultaneous.h"
 #include "RooStreamParser.h"
 #include "RooStringVar.h"
 #include "RooStringView.h"
 #include "RooStudyManager.h"
 #include "RooStudyPackage.h"
 #include "RooSuperCategory.h"
-#include "RooTable.h"
-#include "RooTFoamBinding.h"
-#include "RooThresholdCategory.h"
 #include "RooTObjWrap.h"
+#include "RooTable.h"
+#include "RooTemplateProxy.h"
+#include "RooThresholdCategory.h"
 #include "RooTrace.h"
 #include "RooTreeDataStore.h"
 #include "RooTruthModel.h"
 #include "RooUniformBinning.h"
-#include "RooUnitTest.h"
 #include "RooVectorDataStore.h"
 #include "RooWorkspace.h"
 #include "RooWorkspaceHandle.h"
-#include "RooXYChi2Var.h"
-#include "RooHelpers.h"
 #include "RooWrapperPdf.h"
-#include "RooBinSamplingPdf.h"
-#include "RooBinWidthFunction.h"
-#include "RooFitLegacy/RooCatTypeLegacy.h"
-#include "RooFitLegacy/RooCategorySharedProperties.h"
-#include "RooFitLegacy/RooMinuit.h"
-#include "RooFitLegacy/RooTreeData.h"
-#include "RooFit/TestStatistics/LikelihoodGradientWrapper.h"
-#include "RooFit/TestStatistics/LikelihoodWrapper.h"
-#include "RooFit/TestStatistics/RooAbsL.h"
-#include "RooFit/TestStatistics/RooBinnedL.h"
-#include "RooFit/TestStatistics/RooSubsidiaryL.h"
-#include "RooFit/TestStatistics/RooSumL.h"
-#include "RooFit/TestStatistics/RooRealL.h"
-#include "RooFit/TestStatistics/RooUnbinnedL.h"
-#include "RooFit/TestStatistics/optional_parameter_types.h"
-#include "RooFit/TestStatistics/buildLikelihood.h"
-#include "RunContext.h"
+#include "RooAbsOptTestStatistic.h"
+#include "RooAbsTestStatistic.h"
+#include "RooChi2Var.h"
+#include "RooNLLVar.h"
+#include "RooRealMPFE.h"
+#include "RooXYChi2Var.h"
 // ./roofit/roofit/G__RooFit.cxx
 #include "Roo2DKeysPdf.h"
 #include "RooArgusBG.h"
@@ -2010,8 +2012,8 @@
 #include "RooDecay.h"
 #include "RooDstD0BG.h"
 #include "RooExponential.h"
-#include "RooExpPoly.h"
-#include "RooPower.h"
+#include "RooLegacyExpPoly.h"
+#include "RooPowerSum.h"
 #include "RooFunctor1DBinding.h"
 #include "RooFunctorBinding.h"
 #include "RooGamma.h"
@@ -2029,7 +2031,6 @@
 #include "RooMomentMorphFunc.h"
 #include "RooMomentMorphFuncND.h"
 #include "RooMomentMorph.h"
-#include "RooMomentMorphND.h"
 #include "RooMultiBinomial.h"
 #include "RooNDKeysPdf.h"
 #include "RooNonCPEigenDecay.h"
@@ -2038,6 +2039,7 @@
 #include "RooParamHistFunc.h"
 #include "RooPoisson.h"
 #include "RooPolynomial.h"
+#include "RooSpline.h"
 #include "RooStepFunction.h"
 #include "RooTFnBinding.h"
 #include "RooTFnPdfBinding.h"
@@ -2051,8 +2053,6 @@
 #include "RooJohnson.h"
 // ./roofit/roofitmore/G__RooFitMore.cxx
 #include "RooFitMoreLib.h"
-#include "RooAdaptiveGaussKronrodIntegrator1D.h"
-#include "RooGaussKronrodIntegrator1D.h"
 #include "RooLegendre.h"
 #include "RooMathMoreReg.h"
 #include "RooSpHarmonic.h"
@@ -2148,13 +2148,17 @@
 // ./roofit/hs3/G__RooFitHS3.cxx
 #include "RooFitHS3/JSONIO.h"
 #include "RooFitHS3/RooJSONFactoryWSTool.h"
-#include "RooFitHS3/HistFactoryJSONTool.h"
 // ./roofit/xroofit/G__RooFitXRooFit.cxx
 #include "RooBrowser.h"
+#include "XRooFit.h"
+#include "RooFit/xRooFit/xRooFit.h"
 #include "RooFit/xRooFit/xRooNode.h"
+#include "RooFit/xRooFit/xRooNLLVar.h"
+#include "RooFit/xRooFit/xRooHypoSpace.h"
 #include "RooFit/xRooFit/xRooBrowser.h"
 // ./core/G__Core.cxx
 #include "ROOT/TErrorDefaultHandler.hxx"
+#include "ROOT/TExecutorCRTP.hxx"
 #include "ROOT/TSequentialExecutor.hxx"
 #include "ROOT/StringConv.hxx"
 #include "Buttons.h"
@@ -2238,6 +2242,7 @@
 #include "TVirtualFFT.h"
 #include "TVirtualGL.h"
 #include "TVirtualMonitoring.h"
+#include "TVirtualMapFile.h"
 #include "TVirtualMutex.h"
 #include "TVirtualPadEditor.h"
 #include "TVirtualPad.h"
@@ -2249,11 +2254,13 @@
 #include "TVirtualTableInterface.h"
 #include "TVirtualViewer3D.h"
 #include "TVirtualX.h"
+#include "ROOT/RFloat16.hxx"
 #include "ROOT/RDirectoryEntry.hxx"
 #include "ROOT/RIndexIter.hxx"
 #include "strlcpy.h"
 #include "snprintf.h"
 #include "strtok.h"
+#include "root_std_complex.h"
 #include "ROOT/TSeq.hxx"
 #include "TArrayC.h"
 #include "TArrayD.h"
@@ -2296,8 +2303,7 @@
 #include "ROOT/StringUtils.hxx"
 #include "ROOT/span.hxx"
 #include "ROOT/TypeTraits.hxx"
-#include "TUnixSystem.h"
-#include "root_std_complex.h"
+#include "ROOT/RError.hxx"
 #include "GuiTypes.h"
 #include "TApplicationImp.h"
 #include "TBrowser.h"
@@ -2354,6 +2360,7 @@
 #include "TVirtualArray.h"
 #include "TVirtualObject.h"
 #include "Getline.h"
+#include "TUnixSystem.h"
 // Extra headers
 #include "ROOT/TSeq.hxx"
 #include "ROOT/StringConv.hxx"
