@@ -1,7 +1,7 @@
+#include "etc/dictpch/core/imt/inc/LinkDef.h"
 #include "etc/dictpch/core/multiproc/inc/LinkDef.h"
 #include "etc/dictpch/core/rint/inc/LinkDef.h"
 #include "etc/dictpch/core/thread/inc/LinkDef.h"
-#include "etc/dictpch/core/imt/inc/LinkDef.h"
 #include "etc/dictpch/math/mathcore/inc/LinkDef.h"
 #include "etc/dictpch/math/mathcore/inc/LinkDef1.h"
 #include "etc/dictpch/math/mathcore/inc/LinkDef2.h"
@@ -36,13 +36,14 @@
 #include "etc/dictpch/hist/histdrawv7/inc/LinkDef.h"
 #include "etc/dictpch/hist/spectrum/inc/LinkDef.h"
 #include "etc/dictpch/hist/spectrumpainter/inc/LinkDef.h"
-#include "etc/dictpch/hist/unfold/inc/LinkDef.h"
 #include "etc/dictpch/hist/hbook/inc/LinkDef.h"
 #include "etc/dictpch/tree/tree/inc/LinkDef.h"
 #include "etc/dictpch/tree/treeplayer/inc/LinkDef.h"
 #include "etc/dictpch/tree/treeviewer/inc/LinkDef.h"
+#include "etc/dictpch/tree/webviewer/inc/LinkDef.h"
 #include "etc/dictpch/tree/dataframe/inc/LinkDef.h"
 #include "etc/dictpch/tree/ntuple/inc/LinkDef.h"
+#include "etc/dictpch/tree/ntupleutil/inc/LinkDef.h"
 #include "etc/dictpch/io/io/inc/LinkDef.h"
 #include "etc/dictpch/net/net/inc/LinkDef.h"
 #include "etc/dictpch/net/netxng/inc/LinkDef.h"
@@ -71,6 +72,14 @@
 #include "etc/dictpch/tmva/tmva/inc/LinkDef3.h"
 #include "etc/dictpch/tmva/tmva/inc/LinkDef4.h"
 #include "etc/dictpch/tmva/tmva/inc/LinkDef5.h"
+#include "etc/dictpch/tmva/tmva/inc/LinkDefUtils.h"
+#include "etc/dictpch/tmva/tmva/inc/LinkDef.h"
+#include "etc/dictpch/tmva/tmva/inc/LinkDef1.h"
+#include "etc/dictpch/tmva/tmva/inc/LinkDef2.h"
+#include "etc/dictpch/tmva/tmva/inc/LinkDef3.h"
+#include "etc/dictpch/tmva/tmva/inc/LinkDef4.h"
+#include "etc/dictpch/tmva/tmva/inc/LinkDef5.h"
+#include "etc/dictpch/tmva/tmva/inc/LinkDefUtils.h"
 #include "etc/dictpch/tmva/tmvagui/inc/LinkDef.h"
 #include "etc/dictpch/tmva/pymva/inc/LinkDef.h"
 #include "etc/dictpch/tmva/sofie/inc/LinkDef.h"
@@ -80,6 +89,7 @@
 #include "etc/dictpch/roofit/roostats/inc/LinkDef.h"
 #include "etc/dictpch/roofit/histfactory/inc/LinkDef.h"
 #include "etc/dictpch/roofit/RDataFrameHelpers/inc/LinkDef.h"
+#include "etc/dictpch/roofit/xroofit/inc/LinkDef.h"
 #include "etc/dictpch/core/base/inc/LinkDef.h"
 #include "etc/dictpch/core/base/inc/LinkDef1.h"
 #include "etc/dictpch/core/base/inc/LinkDef2.h"
